##  Limitations
  * You can enable SCIM for a single workspace. SCIM is not supported across multiple workspaces.
  * User state synchronization only works for the workspace where you configure SCIM.
  * If you enabled the Invite Only flow with SSO for your workspace, user permissions are not created with SCIM.
